@@ -57,6 +57,7 @@ struct _XfceNotifyDaemon
     guint bus_name_id;
     gdouble initial_opacity;
     GtkCornerType notify_location;
+    gboolean do_fadeout;
 
     GtkCssProvider *css_provider;
     gboolean is_default_theme;
@@ -661,9 +662,14 @@ xfce_notify_daemon_window_size_allocate(GtkWidget *widget,
     XfceNotifyDaemon *xndaemon = user_data;
     XfceNotifyWindow *window = XFCE_NOTIFY_WINDOW(widget);
     GdkScreen *p_screen = NULL;
+    GdkDevice *pointer;
+#if GTK_CHECK_VERSION (3, 20, 0)
+    GdkSeat *seat;
+#else
     GdkScreen *widget_screen;
     GdkDisplay *display;
-    GdkDevice *pointer;
+    GdkDeviceManager *device_manager;
+#endif
     gint x, y, monitor, screen_n, max_width;
     GdkRectangle *geom_tmp, geom, initial, widget_geom;
     GList *list;
@@ -693,17 +699,13 @@ xfce_notify_daemon_window_size_allocate(GtkWidget *widget,
         xndaemon->reserved_rectangles[screen_n][monitor] = old_list;
     }
 
-    /* All these calls are, well to get replace the deprecated
-     * gdk_display_get_pointer function! Go GTK...*/
-    widget_screen = gtk_widget_get_screen (widget);
-    display = gdk_screen_get_display (widget_screen);
-
 #if GTK_CHECK_VERSION (3, 20, 0)
-    GdkSeat *seat = gdk_display_get_default_seat (gdk_display_get_default());
+    seat = gdk_display_get_default_seat (gdk_display_get_default());
     pointer = gdk_seat_get_pointer (seat);
 #else
-    GdkDeviceManager *device_manager = gdk_display_get_device_manager (display);
-    pointer = gdk_device_manager_get_client_pointer (device_manager);
+    widget_screen = gtk_widget_get_screen (widget);
+    display = gdk_screen_get_display (widget_screen);
+    device_manager = gdk_display_get_device_manager (display);
 #endif
 
     gdk_device_get_position (pointer, &p_screen, &x, &y);
@@ -1039,7 +1041,7 @@ static gboolean notify_notify (XfceNotifyGBus *skeleton,
                                XfceNotifyDaemon *xndaemon)
 {
     XfceNotifyWindow *window;
-    GdkPixbuf *pix;
+    GdkPixbuf *pix = NULL;
     GVariant *image_data = NULL;
     const gchar *desktop_id = NULL;
     gint value_hint = 0;
@@ -1093,6 +1095,8 @@ static gboolean notify_notify (XfceNotifyGBus *skeleton,
         }
         else if (g_strcmp0 (key, "x-canonical-private-icon-only") == 0)
             x_canonical = TRUE;
+
+        g_variant_unref (item);
     }
 
     if(expire_timeout == -1)
@@ -1148,6 +1152,7 @@ static gboolean notify_notify (XfceNotifyGBus *skeleton,
                 xfce_notify_window_set_icon_pixbuf(window, pix);
                 g_object_unref(G_OBJECT(pix));
             }
+            g_variant_unref(image_data);
         } else {
             if(desktop_id) {
                 gchar *resource = g_strdup_printf("applications%c%s.desktop",
@@ -1182,6 +1187,8 @@ static gboolean notify_notify (XfceNotifyGBus *skeleton,
 
     xfce_notify_window_set_icon_only(window, x_canonical);
 
+    xfce_notify_window_set_do_fadeout(window, xndaemon->do_fadeout);
+
     if(value_hint_set)
         xfce_notify_window_set_gauge_value(window, value_hint);
     else
@@ -1349,7 +1356,7 @@ xfce_notify_daemon_set_theme(XfceNotifyDaemon *xndaemon,
                                          &error);
     if (!css_parsed)
     {
-        g_warning ("Faild to parse css file : %s\n", error->message);
+        g_warning ("Failed to parse css file: %s", error->message);
         g_error_free (error);
     }
     else
@@ -1387,6 +1394,10 @@ xfce_notify_daemon_settings_changed(XfconfChannel *channel,
         xndaemon->notify_location = G_VALUE_TYPE(value)
                                   ? g_value_get_uint(value)
                                   : GTK_CORNER_TOP_RIGHT;
+    } else if(!strcmp(property, "/do-fadeout")) {
+        xndaemon->do_fadeout = G_VALUE_TYPE(value)
+                               ? g_value_get_boolean(value)
+                               : TRUE;
     }
 }
 
@@ -1418,6 +1429,9 @@ xfce_notify_daemon_load_config (XfceNotifyDaemon *xndaemon,
                                                       "/notify-location",
                                                       GTK_CORNER_TOP_RIGHT);
 
+    xndaemon->do_fadeout = xfconf_channel_get_bool(xndaemon->settings,
+                                                "/do-fadeout", TRUE);
+
     g_signal_connect(G_OBJECT(xndaemon->settings), "property-changed",
                      G_CALLBACK(xfce_notify_daemon_settings_changed),
                      xndaemon);
